aboutsummaryrefslogtreecommitdiff
path: root/src/google_breakpad/processor/process_state.h
diff options
context:
space:
mode:
authormmandlis@chromium.org <mmandlis@chromium.org>2014-11-19 21:33:26 +0000
committermmandlis@chromium.org <mmandlis@chromium.org>2014-11-19 21:33:26 +0000
commit6354cffeb0c854dac46d81210c59f7037230cc54 (patch)
tree702bba7821fec3f4f5033419be3cc53bceb4718c /src/google_breakpad/processor/process_state.h
parentAdd parameter --product to symupload.exe (diff)
downloadbreakpad-6354cffeb0c854dac46d81210c59f7037230cc54.tar.xz
Microdump processing implementation
According to design document: http://goo.gl/B3wIRN This is an initial implementation version, support ARM architecture only. BUG=chromium:410294 R=primiano@chromium.org Review URL: https://breakpad.appspot.com/5714003 git-svn-id: http://google-breakpad.googlecode.com/svn/trunk@1403 4c0a9323-5329-0410-9bdc-e9ce6186880e
Diffstat (limited to 'src/google_breakpad/processor/process_state.h')
-rw-r--r--src/google_breakpad/processor/process_state.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/google_breakpad/processor/process_state.h b/src/google_breakpad/processor/process_state.h
index 88f826c2..a33b2123 100644
--- a/src/google_breakpad/processor/process_state.h
+++ b/src/google_breakpad/processor/process_state.h
@@ -117,8 +117,10 @@ class ProcessState {
ExploitabilityRating exploitability() const { return exploitability_; }
private:
// MinidumpProcessor is responsible for building ProcessState objects.
friend class MinidumpProcessor;
+ friend class MicrodumpProcessor;
// The time-date stamp of the minidump (time_t format)
uint32_t time_date_stamp_;
@@ -117,8 +117,10 @@ class ProcessState {
ExploitabilityRating exploitability() const { return exploitability_; }
private:
- // MinidumpProcessor is responsible for building ProcessState objects.
+ // MinidumpProcessor and MicrodumpProcessor are responsible for building
+ // ProcessState objects.
friend class MinidumpProcessor;